'use strict';

/**
 * Licensed Materials - Property of IBM
 * IBM Business Analytics (C) Copyright IBM Corp. 2021
 * US Government Users Restricted Rights - Use, duplication or disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
 */

/**
 * @class PageContextUrlExtension
 * @classdesc CA Dashboard extension used to add filters information to the existing share url functionality.
 */
define(['dashboard-core/js/dashboard/glass/controllers/ShareActionHandler'], function (ShareActionHandler) {
	var ShareActionHandlerExtension = ShareActionHandler.extend({
		execute: function execute(context) {
			var share = ShareActionHandlerExtension.inherited('execute', this, arguments);
			var contentView = context.glassContext.appController.getCurrentContentView();
			var dashboard = contentView && contentView.dashboardApi;

			if (share && dashboard) {
				var canvas = dashboard.getFeature('Canvas');
				var globalFilters = dashboard.getFeature('GlobalFilters');
				var dataSources = dashboard.getFeature('DataSources');
				var pages = canvas.findContent({ type: 'page' });

				var pageIds = pages.map(function (page) {
					return page.getId();
				});
				var filters = this._getFilters(globalFilters, dataSources, pageIds);

				share.filters = JSON.stringify(filters);
			}
			return share;
		},

		_getFilters: function _getFilters(globalFilters, dataSources, pageIds) {
			var _this = this;

			var filters = [];
			var dataSourceIds = dataSources.getDataSourceList().map(function (dataSource) {
				return dataSource.getId();
			});
			dataSourceIds.forEach(function (dataSourceId) {
				var assetId = dataSources.getDataSource(dataSourceId).getAssetId();
				filters.push.apply(filters, _this._getFiltersByScopeAndSource(globalFilters, 'global', dataSourceId, assetId));
				pageIds.forEach(function (pageId) {
					filters.push.apply(filters, _this._getFiltersByScopeAndSource(globalFilters, pageId, dataSourceId, assetId));
				});
			});
			return filters;
		},

		_getFiltersByScopeAndSource: function _getFiltersByScopeAndSource(globalFilters, scope, sourceId, assetId) {
			var filters = globalFilters.getFilters(sourceId, scope).getFilterList();
			this._addScopeAndSourceToFilter(filters, assetId, scope);
			return filters;
		},

		_addScopeAndSourceToFilter: function _addScopeAndSourceToFilter(filters, assetId, scope) {
			filters.forEach(function (filter) {
				filter.assetId = assetId;
				filter.scope = scope;
			});
		}
	});
	return ShareActionHandlerExtension;
});
